#!/bin/sh

# make the binaries
echo ""
echo "make binaries"
cd ..
make
cd ABC_bench

# print data
echo ""
echo "DATA:"
echo "A = 8000 A + 2000 AB + 1000 AC + 1000 ABC = 12000 reads"
echo "B = 8000 B + 2000 BA + 1000 BC + 1000 BAC = 12000 reads"
echo "C = 7000 C + 1000 CA + 1000 CB + 1000 CAB = 10000 reads"
# With
# CA = AC
# AB = BA
# CB = BC
# ABC = BAC = CAB

# theoretical similarities
echo ""
echo "THEORETICAL SIMILARITIES:"
echo " A_in_B = (2000 AB + 2000 BA + 1000 ABC + 1000 BAC) / (12000 + 12000) = 6000 / 24000 = 25%"
echo " A_in_C = (1000 AC + 1000 ABC + 1000 CA + 1000 CAB) / (12000 + 10000) = 4000 / 22000 = 18,18%"
echo " B_in_C = (1000 BC + 1000 BAC + 1000 CB + 1000 CAB) / (12000 + 10000) = 4000 / 22000 = 18,18%"

# filter reads
echo ""
echo "Filter A"
../filter_reads A -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"
echo "Filter B"
../filter_reads B -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"
echo "Filter C"
../filter_reads C -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"

# compareads similarities
echo ""
echo "COMPAREADS2 SIMILARITIES (k-mer size = 24):"
../compare_reads -a A,A.bv -b B,B.bv -k 24 2>&1 >/dev/null | grep "Similarity"
../compare_reads -a A,A.bv -b C,C.bv -k 24 2>&1 >/dev/null | grep "Similarity"
../compare_reads -a B,B.bv -b C,C.bv -k 24 2>&1 >/dev/null | grep "Similarity"

# bit vector operations
echo ""
echo "NOT (A_in_B) = 8000 A + 1000 AC = 9000 reads"
../bvop -n A_in_B.bv not_A_in_B.bv 2> /dev/null
../bvop not_A_in_B.bv -a A.bv not_A_in_B.bv 2> /dev/null
../extract_reads A not_A_in_B.bv -o not_A_in_B 2> /dev/null
nb_reads=`grep ">" not_A_in_B | wc -l | tr -d ' '`
echo "nb reads in not_A_in_B          = $nb_reads reads"

echo ""
echo "A_in_B AND A_in_C = 1000 ABC  = 1000 reads"
../bvop A_in_B.bv -a A_in_C.bv A_in_B_and_A_in_C.bv 2> /dev/null
../extract_reads A A_in_B_and_A_in_C.bv -o A_in_B_and_A_in_C 2> /dev/null
nb_reads=`grep ">" A_in_B_and_A_in_C | wc -l | tr -d ' '`
echo "nb reads in A_in_B_and_A_in_C = $nb_reads reads"

echo ""
echo "B_in_A OR B_in_C = 2000 BA + 1000 BC + 1000 ABC = 4000 reads"
../bvop B_in_A.bv -o B_in_C.bv B_in_A_or_B_in_C.bv 2> /dev/null
../extract_reads B B_in_A_or_B_in_C.bv -o B_in_A_or_B_in_C 2> /dev/null
nb_reads=`grep ">" B_in_A_or_B_in_C | wc -l | tr -d ' '`
echo "nb reads in B_in_A_or_B_in_C                    = $nb_reads reads"

echo ""
echo "C_in_A AND (NOT C_in_B) = 1000 CA = 1000 reads"
../bvop C_in_B.bv -n not_C_in_B.bv 2> /dev/null
../bvop C_in_A.bv -a not_C_in_B.bv C_in_A_and_not_C_in_B.bv 2> /dev/null
../extract_reads C C_in_A_and_not_C_in_B.bv -o C_in_A_and_not_C_in_B 2> /dev/null
nb_reads=`grep ">" C_in_A_and_not_C_in_B | wc -l | tr -d ' '`
echo "nb reads in C_in_A_and_not_C_in_B = $nb_reads reads"
echo ""

rm A.bv
rm A_VS_B.log
rm A_VS_C.log
rm A_in_B.bv
rm A_in_B_and_A_in_C
rm A_in_B_and_A_in_C.bv
rm A_in_C.bv
rm B.bv
rm B_VS_C.log
rm B_in_A.bv
rm B_in_A_or_B_in_C
rm B_in_A_or_B_in_C.bv
rm B_in_C.bv
rm C.bv
rm C_in_A.bv
rm C_in_A_and_not_C_in_B
rm C_in_A_and_not_C_in_B.bv
rm C_in_B.bv
rm not_A_in_B
rm not_A_in_B.bv
rm not_C_in_B.bv

# run test on compressed files
sleep 1
echo "Test on compressed files"

# filter reads
echo ""
echo "Filter A.gz"
../filter_reads A.gz -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"
echo "Filter B.gz"
../filter_reads B.gz -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"
echo "Filter C.gz"
../filter_reads C.gz -l 100 -n 5 -e 1.9 2>&1 >/dev/null | grep "Shannon"

# compareads similarities
echo ""
echo "COMPAREADS2 SIMILARITIES (k-mer size = 24):"
../compare_reads -a A.gz,A.gz.bv -b B.gz,B.gz.bv -k 24 2>&1 >/dev/null | grep "Similarity"
../compare_reads -a A.gz,A.gz.bv -b C.gz,C.gz.bv -k 24 2>&1 >/dev/null | grep "Similarity"
../compare_reads -a B.gz,B.gz.bv -b C.gz,C.gz.bv -k 24 2>&1 >/dev/null | grep "Similarity"

# bit vector operations
echo ""
echo "NOT (A.gz_in_B.gz) = 8000 A + 1000 AC = 9000 reads"
../bvop -n A.gz_in_B.gz.bv not_A.gz_in_B.gz.bv 2> /dev/null
../bvop not_A.gz_in_B.gz.bv -a A.gz.bv not_A.gz_in_B.gz.bv 2> /dev/null
../extract_reads A.gz not_A.gz_in_B.gz.bv -o not_A.gz_in_B.gz 2> /dev/null
gunzip not_A.gz_in_B.gz
nb_reads=`grep ">" not_A.gz_in_B | wc -l | tr -d ' '`
echo "nb reads in not_A.gz_in_B             = $nb_reads reads"

echo ""
echo "A.gz_in_.gzB AND A.gz_in_C.gz = 1000 ABC = 1000 reads"
../bvop A.gz_in_B.gz.bv -a A.gz_in_C.gz.bv  A.gz_in_B.gz_and_A.gz_in_C.gz.bv 2> /dev/null
../extract_reads A.gz A.gz_in_B.gz_and_A.gz_in_C.gz.bv -o A.gz_in_B.gz_and_A.gz_in_C.gz 2> /dev/null
gunzip A.gz_in_B.gz_and_A.gz_in_C.gz
nb_reads=`grep ">" A.gz_in_B.gz_and_A.gz_in_C | wc -l | tr -d ' '`
echo "nb reads in A.gz_in_B.gz_and_A.gz_in_C   = $nb_reads reads"

echo ""
echo "B.gz_in_A.gz OR B.gz_in_C.gz = 2000 BA + 1000 BC + 1000 ABC = 4000 reads"
../bvop B.gz_in_A.gz.bv -o B.gz_in_C.gz.bv  B.gz_in_A.gz_or_B.gz_in_C.gz.bv 2> /dev/null
../extract_reads B.gz B.gz_in_A.gz_or_B.gz_in_C.gz.bv -o B.gz_in_A.gz_or_B.gz_in_C.gz 2> /dev/null
gunzip B.gz_in_A.gz_or_B.gz_in_C.gz
nb_reads=`grep ">" B.gz_in_A.gz_or_B.gz_in_C | wc -l | tr -d ' '`
echo "nb reads in B.gz_in_A.gz_or_B.gz_in_C                       = $nb_reads reads"

echo ""
echo "C.gz_in_A.gz AND (NOT C.gz_in_B.gz) = 1000 CA = 1000 reads"
../bvop C.gz_in_B.gz.bv -n  not_C.gz_in_B.gz.bv 2> /dev/null
../bvop C.gz_in_A.gz.bv -a not_C.gz_in_B.gz.bv  C.gz_in_A.gz_and_not_C.gz_in_B.gz.bv 2> /dev/null
../extract_reads C.gz C.gz_in_A.gz_and_not_C.gz_in_B.gz.bv -o C.gz_in_A.gz_and_not_C.gz_in_B.gz 2> /dev/null
gunzip C.gz_in_A.gz_and_not_C.gz_in_B.gz
nb_reads=`grep ">" C.gz_in_A.gz_and_not_C.gz_in_B | wc -l | tr -d ' '`
echo "nb reads in C.gz_in_A.gz_and_not_C.gz_in_B    = $nb_reads reads"
echo ""

rm A.gz.bv
rm A.gz_in_B.gz_and_A.gz_in_C.gz.bv
rm B.gz_in_A.gz.bv
rm C.gz_in_A.gz.bv
rm not_C.gz_in_B.gz.bv
rm A.gz_VS_B.gz.log
rm A.gz_in_C.gz.bv
rm B.gz_in_A.gz_or_B.gz_in_C.gz.bv
rm C.gz_in_A.gz_and_not_C.gz_in_B.gz.bv
rm A.gz_VS_C.gz.log
rm B.gz.bv
rm B.gz_in_C.gz.bv
rm C.gz_in_B.gz.bv
rm A.gz_in_B.gz.bv
rm B.gz_VS_C.gz.log
rm C.gz.bv
rm not_A.gz_in_B.gz.bv
rm A.gz_in_B.gz_and_A.gz_in_C
rm B.gz_in_A.gz_or_B.gz_in_C
rm C.gz_in_A.gz_and_not_C.gz_in_B
rm not_A.gz_in_B

